==> hereditas-0.1.0.tgz: package/README.md <==
# Hereditas

[![Version](https://img.shields.io/npm/v/hereditas.svg)](https://npmjs.org/package/hereditas)
[![Downloads/week](https://img.shields.io/npm/dw/hereditas.svg)](https://npmjs.org/package/hereditas)
[![License](https://img.shields.io/npm/l/hereditas.svg)](https://github.com/ItalyPaleAle/hereditas/blob/master/package.json)

## What happens to your digital life after you're gone?

![Hereditas logo](./assets/hereditas-logo.png)

Hereditas, which means *inheritance* in Latin, is a static website generator that builds **fully-trustless digital legacy boxes**, where you can store information for your relatives to access in case of your sudden death or disappearance.

For example, you could use this to pass information such as passwords, cryptographic keys, cryptocurrency wallets, sensitive documents, etc.

## Learn more

Read the [Hereditas announcement](https://withblue.ink/2019/03/19/what-happens-to-your-digital-life-after-youre-gone-introducing-hereditas.html?utm_source=web&utm_campaign=hereditas-github) to understand more on why we need Hereditas.

You can also watch this intro video: **YOUTUBE LINK GOES HERE**

## Get started and documentation

❓ [**What is Hereditas**](https://hereditas.app)

🚀 [**Get started guide**](https://hereditas.app/guides/get-started.html)

🔐 [**Security model**](https://hereditas.app/introduction/security-model.html)

📘 [**Documentation and CLI reference**](https://hereditas.app)

## Warning: alpha quality software

**Hereditas is currently alpha quality software; use at your own risk.** While we've developed Hereditas with security always as the top priority, this software leverages a lot of cryptographic primitives under the hood. We won't release a stable (e.g. "1.0") version of Hereditas until we're confident that enough people and cryptography experts have audited and improved the code.

**Your help is highly appreciated.** If you are an expert on security or cryptography, please help us reviewing the code and let us know what you think - including if everything looks fine, or if you found a bug.

Responsible disclosure: if you believe you've found a security issue that could compromise current users of Hereditas, please [report it confidentially](https://www.npmjs.com/advisories/report?package=hereditas).

## License

Copyright © 2019, Alessandro Segala @ItalyPaleAle

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You can read the full text of the license in the [LICENSE.md](./LICENSE.md) file.

==> hereditas-0.1.1.tgz: package/README.md <==
# Hereditas

[![Version](https://img.shields.io/npm/v/hereditas.svg)](https://npmjs.org/package/hereditas)
[![Downloads/week](https://img.shields.io/npm/dw/hereditas.svg)](https://npmjs.org/package/hereditas)
[![License](https://img.shields.io/npm/l/hereditas.svg)](https://github.com/ItalyPaleAle/hereditas/blob/master/package.json)

## What happens to your digital life after you're gone?

![Hereditas logo](./assets/hereditas-logo.png)

Hereditas, which means *inheritance* in Latin, is a static website generator that builds **fully-trustless digital legacy boxes**, where you can store information for your relatives to access in case of your sudden death or disappearance.

For example, you could use this to pass information such as passwords, cryptographic keys, cryptocurrency wallets, sensitive documents, etc.

## Learn more

Read the [Hereditas announcement](https://withblue.ink/2019/03/18/what-happens-to-your-digital-life-after-youre-gone-introducing-hereditas.html?utm_source=web&utm_campaign=hereditas-github) to understand more on why we need Hereditas.

You can also watch this short [intro video](https://www.youtube.com/watch?v=lZEKgB5dzQ4).

## Get started and documentation

❓ [**What is Hereditas**](https://hereditas.app)

🚀 [**Get started guide**](https://hereditas.app/guides/get-started.html)

🔐 [**Security model**](https://hereditas.app/introduction/security-model.html)

📘 [**Documentation and CLI reference**](https://hereditas.app)

## Warning: alpha quality software

**Hereditas is currently alpha quality software; use at your own risk.** While we've developed Hereditas with security always as the top priority, this software leverages a lot of cryptographic primitives under the hood. We won't release a stable (e.g. "1.0") version of Hereditas until we're confident that enough people and cryptography experts have audited and improved the code.

**Your help is highly appreciated.** If you are an expert on security or cryptography, please help us reviewing the code and let us know what you think - including if everything looks fine, or if you found a bug.

Responsible disclosure: if you believe you've found a security issue that could compromise current users of Hereditas, please [report it confidentially](https://www.npmjs.com/advisories/report?package=hereditas).

## License

Copyright © 2019, Alessandro Segala @ItalyPaleAle

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You can read the full text of the license in the [LICENSE.md](./LICENSE.md) file.
